@@ -13,6 +13,7 @@ import json
 import zlib
 import base64
 import logging
+import warnings
 from functools import wraps
 
 from lambda_proxy import templates
@@ -87,6 +88,7 @@ class RouteEntry(object):
         payload_compression_method: str = "",
         binary_b64encode: bool = False,
         ttl=None,
+        cache_control=None,
         description: str = None,
         tag: Tuple = None,
     ) -> None:
@@ -101,6 +103,7 @@ class RouteEntry(object):
         self.compression = payload_compression_method
         self.b64encode = binary_b64encode
         self.ttl = ttl
+        self.cache_control = cache_control
         self.description = description or self.endpoint.__doc__
         self.tag = tag
         if self.compression and self.compression not in ["gzip", "zlib", "deflate"]:
@@ -355,16 +358,24 @@ class API(object):
 
         return False
 
-    def _add_route(self, path: str, endpoint: callable, **kwargs) -> None:
+    def _add_route(self, path: str, endpoint: Callable, **kwargs) -> None:
         methods = kwargs.pop("methods", ["GET"])
         cors = kwargs.pop("cors", False)
         token = kwargs.pop("token", "")
         payload_compression = kwargs.pop("payload_compression_method", "")
         binary_encode = kwargs.pop("binary_b64encode", False)
         ttl = kwargs.pop("ttl", None)
+        cache_control = kwargs.pop("cache_control", None)
         description = kwargs.pop("description", None)
         tag = kwargs.pop("tag", None)
 
+        if ttl:
+            warnings.warn(
+                "ttl will be deprecated in 6.0.0, please use 'cache-control'",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
         if kwargs:
             raise TypeError(
                 "TypeError: route() got unexpected keyword "
@@ -386,6 +397,7 @@ class API(object):
             payload_compression,
             binary_encode,
             ttl,
+            cache_control,
             description,
             tag,
         )
@@ -424,7 +436,7 @@ class API(object):
 
         return False
 
-    def route(self, path: str, **kwargs) -> callable:
+    def route(self, path: str, **kwargs) -> Callable:
         """Register route."""
 
         def _register_view(endpoint):
@@ -433,20 +445,20 @@ class API(object):
 
         return _register_view
 
-    def pass_context(self, f: callable) -> callable:
+    def pass_context(self, f: Callable) -> Callable:
         """Decorator: pass the API Gateway context to the function."""
 
         @wraps(f)
-        def new_func(*args, **kwargs) -> callable:
+        def new_func(*args, **kwargs) -> Callable:
             return f(self.context, *args, **kwargs)
 
         return new_func
 
-    def pass_event(self, f: callable) -> callable:
+    def pass_event(self, f: Callable) -> Callable:
         """Decorator: pass the API Gateway event to the function."""
 
         @wraps(f)
-        def new_func(*args, **kwargs) -> callable:
+        def new_func(*args, **kwargs) -> Callable:
             return f(self.event, *args, **kwargs)
 
         return new_func
@@ -504,6 +516,7 @@ class API(object):
         compression: str = "",
         b64encode: bool = False,
         ttl: int = None,
+        cache_control: str = None,
     ):
         """Return HTTP response.
 
@@ -533,8 +546,10 @@ class API(object):
             "image/jp2",
         ]
 
-        messageData = {
-            "statusCode": statusCode[status],
+        status = statusCode[status] if isinstance(status, str) else status
+
+        messageData: Dict[str, Any] = {
+            "statusCode": status,
             "headers": {"Content-Type": content_type},
         }
 
@@ -576,7 +591,11 @@ class API(object):
 
         if ttl:
             messageData["headers"]["Cache-Control"] = (
-                f"max-age={ttl}" if status == "OK" else "no-cache"
+                f"max-age={ttl}" if status == 200 else "no-cache"
+            )
+        elif cache_control:
+            messageData["headers"]["Cache-Control"] = (
+                cache_control if status == 200 else "no-cache"
             )
 
         if (
@@ -676,4 +695,5 @@ class API(object):
             compression=route_entry.compression,
             b64encode=route_entry.b64encode,
             ttl=route_entry.ttl,
+            cache_control=route_entry.cache_control,
         )
